==> aTunes_1.12.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/AddFavoriteRadioAction.java <==
/*
 * aTunes 1.12.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.handlers.RadioHandler;
import net.sourceforge.atunes.kernel.modules.navigator.NavigationViews;
import net.sourceforge.atunes.kernel.modules.navigator.RadioNavigationView;
import net.sourceforge.atunes.kernel.modules.radio.Radio;
import net.sourceforge.atunes.utils.LanguageTool;

public class AddFavoriteRadioAction extends AbstractAction {

	/**
	 * 
	 */
	private static final long serialVersionUID = 82199784140877040L;

	AddFavoriteRadioAction() {
		super(LanguageTool.getString("ADD_FAVORITE_RADIO"), ImageLoader.RADIO_FAVORITE);
		putValue(SHORT_DESCRIPTION, LanguageTool.getString("RADIO_VIEW_TOOLTIP"));
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		TreePath path = NavigationViews.getView(RadioNavigationView.class).getTree().getSelectionPath();
		Object o = ((DefaultMutableTreeNode) path.getLastPathComponent()).getUserObject();
		if (o instanceof Radio) {
			RadioHandler.getInstance().addRadio((Radio) o);
		}
	}

}

==> aTunes_1.13.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/AddFavoriteRadioAction.java <==
/*
 * aTunes 1.13.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.modules.navigator.NavigationViews;
import net.sourceforge.atunes.kernel.modules.navigator.RadioNavigationView;
import net.sourceforge.atunes.kernel.modules.radio.Radio;
import net.sourceforge.atunes.kernel.modules.radio.RadioHandler;
import net.sourceforge.atunes.utils.LanguageTool;

public class AddFavoriteRadioAction extends AbstractAction {

    private static final long serialVersionUID = 82199784140877040L;

    AddFavoriteRadioAction() {
        super(LanguageTool.getString("ADD_FAVORITE_RADIO"), ImageLoader.RADIO_FAVORITE);
        putValue(SHORT_DESCRIPTION, LanguageTool.getString("RADIO_VIEW_TOOLTIP"));
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        TreePath path = NavigationViews.getView(RadioNavigationView.class).getTree().getSelectionPath();
        Object o = ((DefaultMutableTreeNode) path.getLastPathComponent()).getUserObject();
        if (o instanceof Radio) {
            RadioHandler.getInstance().addRadio((Radio) o);
        }
    }

}
